using System;
using System.Linq;
using System.Threading.Tasks;
using System.Collections.Generic;

using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.Extensions.Logging;


using SwaggerStudy.Services;

namespace SwaggerStudy
{
    /// <summary>
    /// 不使用 Swagger
    /// </summary>
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        public void ConfigureServices(IServiceCollection services)
        {
            services
                .AddControllers()
                //配置System.Text.Json选项
                .AddJsonOptions(jsonOption=> 
                {
                    //整齐打印：压缩格式(一行)还是整齐格式(换行)
                    jsonOption.JsonSerializerOptions.WriteIndented = true;
                    //允许(忽略)对象或数据末尾多余的逗号
                    jsonOption.JsonSerializerOptions.AllowTrailingCommas = true;
                    //自定义时间格式转换器
                    jsonOption.JsonSerializerOptions.Converters.Add(new DatetimeJsonConverter());
                    //转义字符串编码器：直接显示中文
                    jsonOption.JsonSerializerOptions.Encoder= System.Text.Encodings.Web.JavaScriptEncoder.Create(System.Text.Unicode.UnicodeRanges.All);
                });

            services.AddTransient<StudentServer>();
        }

        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseRouting();

            app.UseAuthorization();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllers();
            });
        }
    }
}
